CREATE SCHEMA music;

CREATE TABLE countries ( 
	country_id           integer  NOT NULL,
	country_name         varchar(100)  NOT NULL,
	CONSTRAINT pk_countries PRIMARY KEY ( country_id )
 );

CREATE TABLE genres ( 
	genre_id             integer  NOT NULL,
	genre_name           varchar(100)  NOT NULL,
	CONSTRAINT pk_genres PRIMARY KEY ( genre_id )
 );

CREATE TABLE songs ( 
	song_id              integer  NOT NULL,
	song_title           varchar(100)  NOT NULL,
	song_duration        integer  NOT NULL,
	CONSTRAINT pk_songs PRIMARY KEY ( song_id )
 );

CREATE TABLE artists ( 
	artist_id            integer  NOT NULL,
	genre_id             integer  NOT NULL,
	country_id           integer  NOT NULL,
	artist_site_url      varchar(100)  ,
	CONSTRAINT pk_artists PRIMARY KEY ( artist_id )
 );

CREATE INDEX idx_artists ON artists ( country_id );

CREATE INDEX idx_artists_0 ON artists ( genre_id );

CREATE TABLE groups ( 
	artist_id            integer  NOT NULL,
	group_name           varchar(100)  NOT NULL,
	CONSTRAINT pk_groups PRIMARY KEY ( artist_id )
 );

CREATE TABLE persons ( 
	artist_id            integer  NOT NULL,
	last_name            varchar(100)  NOT NULL,
	first_name           varchar(100)  NOT NULL,
	birthday             date  NOT NULL,
	sex                  char(1)  NOT NULL,
	CONSTRAINT pk_persons PRIMARY KEY ( artist_id )
 );

ALTER TABLE persons ADD CONSTRAINT ck_0 CHECK ( sex = 'M' or sex = 'F' );

COMMENT ON COLUMN persons.sex IS 'M - male, F - female';

CREATE TABLE albums ( 
	album_id             integer  NOT NULL,
	artist_id            integer  NOT NULL,
	album_title          varchar(100)  NOT NULL,
	album_year           integer  NOT NULL,
	album_tracks         integer  NOT NULL,
	CONSTRAINT pk_albums PRIMARY KEY ( album_id )
 );

CREATE INDEX idx_albums ON albums ( artist_id );

CREATE TABLE albums_songs ( 
	album_id             integer  NOT NULL,
	song_id              integer  NOT NULL,
	track_number         integer  NOT NULL,
	CONSTRAINT pk_albums_songs PRIMARY KEY ( album_id, song_id )
 );

ALTER TABLE albums ADD CONSTRAINT fk_albums_artists FOREIGN KEY ( artist_id ) REFERENCES artists( artist_id );

ALTER TABLE albums_songs ADD CONSTRAINT fk_albums_songs_albums FOREIGN KEY ( album_id ) REFERENCES albums( album_id );

ALTER TABLE albums_songs ADD CONSTRAINT fk_albums_songs_songs FOREIGN KEY ( song_id ) REFERENCES songs( song_id );

ALTER TABLE artists ADD CONSTRAINT fk_artists_countries FOREIGN KEY ( country_id ) REFERENCES countries( country_id );

ALTER TABLE artists ADD CONSTRAINT fk_artists_genres FOREIGN KEY ( genre_id ) REFERENCES genres( genre_id );

ALTER TABLE groups ADD CONSTRAINT fk_groups_artists FOREIGN KEY ( artist_id ) REFERENCES artists( artist_id );

ALTER TABLE persons ADD CONSTRAINT fk_persons_artists FOREIGN KEY ( artist_id ) REFERENCES artists( artist_id );

